@@ -21,9 +21,11 @@ transformers_logging.set_verbosity_error()
 class Imagine:
     def __init__(self,
                  model_name: str = config.DEFAULT_MODEL,
+                 control_model_name: str = None,
                  half_mode: bool = None,
                  precision="autocast",
-                 for_inpainting: bool = False):
+                 for_inpainting: bool = False
+                 ):
         """
         Initialize the Imagine class.
         :param model_name: the name of the SD model to use.
@@ -32,9 +34,11 @@ class Imagine:
         :param for_inpainting: whether to use the model for inpainting.
         """
         self.model_name = model_name
+        self.control_model_name = control_model_name
         self.half_mode = half_mode
         self.precision = precision
         model_config = config.get_model_config(model_name)
+        control_model_config = config.get_control_model_config(self.control_model_name)
 
         if model_config is None:
             raise ValueError(f"Unknown model name: {model_name}")
@@ -42,6 +46,7 @@ class Imagine:
         self.sd_model = get_diffusion_model(
             weights_location=model_config.weights_url,
             config_path=model_config.config_path,
+            control_weights_location=control_model_config.weights_url,
             half_mode=half_mode,
             for_inpainting=for_inpainting,
         )
